@@ -3,17 +3,22 @@ import json
 import requests
 
 class Endereco:
+
+    result = ''
+    
     def __init__(self,descricao):
-        self.descricao = descricao
+        self.__descricao = descricao
+        self.__call__()
 
     def __call__(self):
         url = "https://buscacepinter.correios.com.br/app/endereco/carrega-cep-endereco.php"
-        payload = {'endereco': self.descricao,'tipoCEP': 'ALL'}
+        payload = {'endereco': self.__descricao,'tipoCEP': 'ALL'}
         response = requests.request("POST", url, headers={}, data=payload)
-        return response.text
+        self.result = response.text
+        return self.result
     
     def __convert__(self):
-        return json.loads(self.__call__())
+        return json.loads(self.result)
 
     def mensagem(self):
         return self.__convert__()["mensagem"]
@@ -22,4 +27,4 @@ class Endereco:
         return self.__convert__()["total"]
     
     def resultados(self):
-        return self.__convert__()["dados"]
\ No newline at end of file
+        return self.__convert__()["dados"]
